@@ -10,7 +10,7 @@ use warnings;
 use 5.010;  # //
 use base qw( IO::Async::Notifier );
 
-our $VERSION = '0.46';
+our $VERSION = '0.47';
 
 our $DEFAULT_UA = "Perl + " . __PACKAGE__ . "/$VERSION";
 our $DEFAULT_MAXREDIR = 3;
@@ -31,7 +31,9 @@ use IO::Async::Loop 0.59; # ->connect( handle ) ==> $stream
 use Future 0.28; # ->set_label
 use Future::Utils 0.16 qw( repeat );
 
-use Metrics::Any 0.03 '$metrics';
+use Metrics::Any 0.05 '$metrics',
+   strict      => 1,
+   name_prefix => [qw( http client )];
 
 use Scalar::Util qw( blessed reftype );
 use Time::HiRes qw( time );
@@ -131,28 +133,24 @@ the same hostname.
 
 =cut
 
-$metrics->make_gauge( in_flight =>
-   name        => [qw( http client requests_in_flight )],
+$metrics->make_gauge( requests_in_flight =>
    description => "Count of the number of requests sent that have not yet been completed",
    # no labels
 );
 $metrics->make_counter( requests  =>
-   name        => [qw( http client requests )],
    description => "Number of HTTP requests sent",
    labels      => [qw( method )],
 );
 $metrics->make_counter( responses =>
-   name        => [qw( http client responses )],
    description => "Number of HTTP responses received",
    labels      => [qw( method code )],
 );
-$metrics->make_timer( duration =>
-   name        => [qw( http client request duration )],
+$metrics->make_timer( request_duration =>
    description => "Duration of time spent waiting for responses",
    # no labels
 );
-$metrics->make_distribution( response_size =>
-   name        => [qw( http client response bytes )],
+$metrics->make_distribution( response_bytes =>
+   name        => [qw( response bytes )],
    description => "The size in bytes of responses received",
    units       => "bytes",
    # no labels
@@ -775,8 +773,8 @@ sub _do_one_request
    }
 
    if( $metrics ) {
-      $metrics->inc_gauge( in_flight => );
-      $metrics->inc_counter( requests => $request->method );
+      $metrics->inc_gauge( requests_in_flight => );
+      $metrics->inc_counter( requests => [ method => $request->method ] );
    }
 
    return $self->get_connection(
@@ -806,11 +804,11 @@ sub _do_one_request
             my ( $ctx ) = @_;
 
             if( $metrics ) {
-               $metrics->dec_gauge( in_flight => );
+               $metrics->dec_gauge( requests_in_flight => );
                # TODO: Some sort of error counter instead for errors?
-               $metrics->inc_counter( responses => $request->method, $ctx->resp_header->code );
-               $metrics->inc_timer_by( duration => time - $start_time );
-               $metrics->inc_distribution_by( response_size => $ctx->resp_bytes );
+               $metrics->inc_counter( responses => [ method => $request->method, code => $ctx->resp_header->code ] );
+               $metrics->report_timer( request_duration => time - $start_time );
+               $metrics->report_distribution( response_bytes => $ctx->resp_bytes );
             }
          },
       );
